@@ -121,8 +121,8 @@ def _scale(surface, width, height):
     if surface.get_width() == width and surface.get_height() == height:
         return surface.copy()
 
-    width = int(round(width))
-    height = int(round(height))
+    width = round(width)
+    height = round(height)
     if sge.game.scale_method == "smooth":
         try:
             new_surf = pygame.transform.smoothscale(surface, (width, height))
@@ -241,8 +241,8 @@ def _set_mode():
 
         w = max(1, game_window.get_width())
         h = max(1, game_window.get_height())
-        game_x = int(round((w - game.width * game_xscale) / 2))
-        game_y = int(round((h - game.height * game_yscale) / 2))
+        game_x = round((w - game.width*game_xscale) / 2)
+        game_y = round((h - game.height*game_yscale) / 2)
     else:
         game_x = 0
         game_y = 0
@@ -267,8 +267,8 @@ def _set_mode():
 
         w = max(1, game_window.get_width())
         h = max(1, game_window.get_height())
-        game_x = int(round((w - game.width * game_xscale) / 2))
-        game_y = int(round((h - game.height * game_yscale) / 2))
+        game_x = round((w - game.width*game_xscale) / 2)
+        game_y = round((h - game.height*game_yscale) / 2)
 
 
 def _get_channel():
@@ -333,8 +333,8 @@ def _get_dot_sprite(color):
 
 def _get_line_sprite(x1, y1, x2, y2, color, thickness, anti_alias):
     # Return a sprite for the given line.
-    w = int(round(abs(x2 - x1) + thickness))
-    h = int(round(abs(y2 - y1) + thickness))
+    w = round(abs(x2 - x1) + thickness)
+    h = round(abs(y2 - y1) + thickness)
     i = ("line_sprite", x1, y1, x2, y2, tuple(color), thickness, anti_alias)
     sprite = cache.get(i)
     if sprite is None:
@@ -816,14 +816,14 @@ def r_update_fade(self, complete):
     h = transition_sprite.height
     if complete < 0.5:
         diff = (complete - self.rd["t_complete_last"]) * 2
-        c = sge.gfx.Color([int(round(diff * 255))] * 3)
+        c = sge.gfx.Color([round(diff * 255)] * 3)
         darkener = sge.gfx.Sprite(width=w, height=h)
         darkener.draw_rectangle(0, 0, w, h, c)
         transition_sprite.draw_sprite(darkener, 0, 0, 0,
                                       blend_mode=sge.BLEND_RGB_SUBTRACT)
     else:
         complete = (complete - 0.5) * 2
-        c = sge.gfx.Color((0, 0, 0, int(round(255 - complete * 255))))
+        c = sge.gfx.Color((0, 0, 0, round(255 - complete * 255)))
         transition_sprite.draw_clear()
         transition_sprite.draw_rectangle(0, 0, w, h, fill=c)
 
@@ -833,7 +833,7 @@ def r_update_dissolve(self, complete):
     w = transition_sprite.width
     h = transition_sprite.height
     diff = complete - self.rd["t_complete_last"]
-    c = sge.gfx.Color((0, 0, 0, int(round(diff * 255))))
+    c = sge.gfx.Color((0, 0, 0, round(diff * 255)))
     eraser = sge.gfx.Sprite(width=w, height=h)
     eraser.draw_rectangle(0, 0, w, h, c)
     transition_sprite.draw_sprite(eraser, 0, 0, 0,
@@ -841,23 +841,29 @@ def r_update_dissolve(self, complete):
 
 
 def r_update_pixelate(self, complete):
+    if not self.rd["t_meta"]:
+        self.rd["t_meta"] = 0
+    if not self.rd["t_arg"]:
+        self.rd["t_arg"] = 0
     transition_sprite = self.rd["t_sprite"]
     w = transition_sprite.width
     h = transition_sprite.height
     scale_method = sge.game.scale_method
     sge.game.scale_method = None
 
-    if complete < 0.8:
-        complete *= 1.25
-        swidth = max(1, w * (1 - complete))
-        sheight = max(1, h * (1 - complete))
-        transition_sprite.width = swidth
-        transition_sprite.height = sheight
-        transition_sprite.width = w
-        transition_sprite.height = h
+    if complete < 0.9:
+        if self.rd["t_time_passed"] - self.rd["t_meta"] > self.rd["t_arg"]:
+            self.rd["t_meta"] = self.rd["t_time_passed"]
+            transition_sprite = self.rd["t_sprite_original"].copy()
+            complete /= 0.9
+            swidth = max(w / 20, w * (1 - complete))
+            sheight = max(h / 20, h * (1 - complete))
+            transition_sprite.size = swidth, sheight
+            transition_sprite.size = w, h
+            self.rd["t_sprite"] = transition_sprite
     else:
         diff = (complete - self.rd["t_complete_last"]) * 5
-        c = sge.gfx.Color((0, 0, 0, int(round(diff * 255))))
+        c = sge.gfx.Color((0, 0, 0, round(diff * 255)))
         eraser = sge.gfx.Sprite(width=w, height=h)
         eraser.draw_rectangle(0, 0, w, h, c)
         transition_sprite.draw_sprite(eraser, 0, 0, 0,
@@ -1031,8 +1037,8 @@ def s_set_size(self):
     # destructive and irreversible.  It is necessary for the drawing
     # methods to work properly, specifically whenever ``width`` and
     # ``height`` are set.
-    width = int(round(self.width))
-    height = int(round(self.height))
+    width = round(self.width)
+    height = round(self.height)
     for i in range(self.frames):
         if sge.game.scale_method == "smooth":
             try:
@@ -1150,8 +1156,8 @@ def s_get_precise_mask(self, num, xscale, yscale, rotation):
         xflip = xscale < 0
         yflip = yscale < 0
         image = pygame.transform.flip(image, xflip, yflip)
-        w = int(round(self.width * abs(xscale)))
-        h = int(round(self.height * abs(yscale)))
+        w = round(self.width * abs(xscale))
+        h = round(self.height * abs(yscale))
         image = pygame.transform.scale(image, (w, h))
         if rotation:
             image = pygame.transform.rotate(image, -rotation)
@@ -1176,22 +1182,23 @@ def s_get_precise_mask(self, num, xscale, yscale, rotation):
 
 
 def s_from_text(cls, font, text, width, height, color, halign, valign,
-                anti_alias):
+                anti_alias, outline, outline_thickness):
     # Version of gfx.Sprite.from_text which always returns the same
     # sprite, to avoid unnecessary duplication for things like
     # projections.
     f_name = tuple(font.name) if font.name is not None else None
     i = ("text_sprite", cls, f_name, font.size, font.underline, font.bold,
          font.italic, text, width, height, str(color), halign, valign,
-         anti_alias)
+         anti_alias, str(outline), outline_thickness)
     s = cache.get(i)
     if s is None:
-        w = font.get_width(text, width, height)
-        h = font.get_height(text, width, height)
+        w = font.get_width(text, width, height) + 2*outline_thickness
+        h = font.get_height(text, width, height) + 2*outline_thickness
         x = {"left": 0, "right": w, "center": w / 2}.get(halign.lower(), 0)
         y = {"top": 0, "bottom": h, "middle": h / 2}.get(valign.lower(), 0)
         s = cls(width=w, height=h, origin_x=x, origin_y=y)
-        s.draw_text(font, text, x, y, width, height, color, halign, valign)
+        s.draw_text(font, text, x, y, width, height, color, halign, valign,
+                    outline=outline, outline_thickness=outline_thickness)
 
     cache.add(i, s)
     return s
